# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/apache-bsf/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free

Name:           bsf
Version:        2.4.0
Release:        11%{?dist}
Epoch:          0
Summary:        Bean Scripting Framework
License:        ASL 2.0
Group:          Development/Libraries/Java
URL:            http://jakarta.apache.org/bsf/
#Source0:       http://archive.apache.org/dist/jakarta/bsf/source/bsf-src-2.4.0.tar.gz
# <https://issues.apache.org/jira/browse/BSF-12>
# Also missing xdocs
# svn export http://svn.apache.org/repos/asf/jakarta/bsf/tags/bsf-2.4.0
Source0:        bsf-2.4.0.tar.bz2
Source1:        bsf-component-info.xml
Source2:        bsf-2.4.0.pom
Patch0:         bsf-javadoc-crosslink.patch
Requires(post): jpackage-utils >= 0:1.7.5
Requires(postun): jpackage-utils >= 0:1.7.5
Requires:       jakarta-commons-logging
Requires:       jpackage-utils
Requires:       jsp_2_1_api
Requires:       xalan-j2
Requires:       servlet_2_5_api
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  jakarta-commons-logging
BuildRequires:  jakarta-commons-logging-javadoc
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  java-javadoc
BuildRequires:  jpackage-utils
BuildRequires:  jsp_2_1_api
BuildRequires:  jacl
BuildRequires:  jython
BuildRequires:  rhino
BuildRequires:  servlet_2_5_api
BuildRequires:  velocity14
BuildRequires:  xalan-j2
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Bean Scripting Framework (BSF) is a set of Java classes which provides
scripting language support within Java applications, and access to Java
objects and methods from scripting languages. BSF allows one to write
JSPs in languages other than Java while providing access to the Java
class library. In addition, BSF permits any Java application to be
implemented in part (or dynamically extended) by a language that is
embedded within it. This is achieved by providing an API that permits
calling scripting language engines from within Java, as well as an
object registry that exposes Java objects to these scripting language
engines.

BSF supports several scripting languages currently:
* Javascript (using Rhino ECMAScript, from the Mozilla project)
* Python (using either Jython or JPython)
* Tcl (using Jacl)
* NetRexx (an extension of the IBM REXX scripting language in Java)
* XSLT Stylesheets (as a component of Apache XML project's Xalan and
Xerces)

In addition, the following languages are supported with their own BSF
engines:
* Java (using BeanShell, from the BeanShell project)
* JRuby
* JudoScript

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Requires:       jpackage-utils

%description javadoc
Javadoc for %{name}.

%package manual
Summary:        Manual for %{name}
Group:          Development/Documentation

%description manual
Manual for %{name}.

%prep
%setup -q
%patch0 -p1 -b .sav0
%{_bindir}/find -name "*.jar" | %{_bindir}/xargs -t %{__rm}
%{__rm} -r docs/
%{__perl} -pi -e 's/\r$//g' samples/scriptedui/ui.{jacl,py}

%build
export OPT_JAR_LIST="ant/ant-junit junit"
export CLASSPATH=$(build-classpath commons-logging jacl jsp_2_1_api jython rhino servlet_2_5_api xalan-j2)
export CLASSPATH=${CLASSPATH}:$(build-classpath excalibur/avalon-logkit commons-collections commons-lang jdom velocity14)
%{ant} -Dbuild.sysclasspath=first -Djava.javadoc=%{_javadocdir}/java -Dcommons.logging.javadoc=%{_javadocdir}/jakarta-commons-logging all \
%if 0
test
%endif

%install
%{__rm} -rf %{buildroot}

# jar
%{__install} -d -m 755 %{buildroot}%{_javadir}
%{__install} -p -m 644 dist/bsf-%{version}/lib/bsf.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do ln -s ${jar} ${jar/-%{version}/}; done)

# pom and depmap frag
%{__install} -d -m 755 %{buildroot}%{_datadir}/maven2/poms
%{__install} -p -m 644 %{SOURCE2} %{buildroot}%{_datadir}/maven2/poms/JPP-bsf.pom
%add_to_maven_depmap bsf bsf %{version} JPP %{name}

# javadoc
%{__install} -d -m 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -pr dist/bsf-%{version}/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
(cd %{buildroot}%{_javadocdir} && ln -s %{name}-%{version} %{name})

%if %with repolib
%{__install} -d -m 755 %{buildroot}%{repodir}
%{__install} -d -m 755 %{buildroot}%{repodirlib}
%{__install} -p -m 644 %{SOURCE1} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__install} -d -m 755 %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{SOURCE0} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_javadir}/bsf.jar %{buildroot}%{repodirlib}
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc dist/bsf-%{version}/{AUTHORS.txt,BUILDING.txt,CHANGES.txt,INSTALL.txt,LICENSE.txt,NOTICE.txt,README.txt,RELEASE-NOTE.txt,samples/,TODO.txt}
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%doc docs/*

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}
%{_javadir}/repository.jboss.com
%endif

%changelog
* Tue Oct 06 2011 David Walluck <dwalluck@redhat.com> 0:2.4.0-11
- fix depmap install
- remove GCJ support
- fix repolib option
- bump release (for mdv)

* Thu Feb 10 2011 David Walluck <dwalluck@redhat.com> 0:2.4.0-3
- use servlet_2_5_api

* Wed Jan 07 2009 David Walluck <dwalluck@redhat.com> 0:2.4.0-2
- bump release

* Mon Dec 22 2008 David Walluck <dwalluck@redhat.com> 0:2.4.0-1
- 2.4.0

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 2.3.0-13
- Auto rebuild for JPackage 5 in mock

* Fri Jun 20 2008 Ralph Apel <r.apel at r-apel.de> 0:2.3.0-12.jpp5
- Add pom and depmap frag

* Tue May 27 2008 Permaine Cheung <pcheung@redhat.com> 0:2.3.0-11jpp
- First JPP 5 build
- Add repolib subpackage

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.3.0-6jpp.ep1.2
- Fix repolib location

* Tue Mar 13 2007 Fernando Nasser <fnasser@redhat.com> 0:2.3.0-6jpp.ep1.1
- New repolib location

* Mon Feb 19 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.3.0-6jpp.el4ep1.2
- Add -brew suffix

* Fri Feb 16 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.3.0-6jpp.el4ep1.1
- Add repolib support
- Use servletapi4 instead of servletapi3

* Mon Nov 15 2004 Fernando Nasser <fnasser@redhat.com> 0:2.3.0-6jpp_2rh
- Rebuild

* Thu Mar  4 2004 Frank Ch. Eigler <fche@redhat.com> 0:2.3.0-6jpp_1rh
- RH vacuuming

* Thu Oct 09 2003 David Walluck <david@anti-microsoft.org> 0:2.3.0-6jpp
- add javadoc symlinks
- change Apache Software License to Apache License

* Tue Aug 26 2003 David Walluck <david@anti-microsoft.org> 0:2.3.0-5jpp
- remove all Requires

* Fri Apr 12 2003 David Walluck <david@anti-microsoft.org> 0:2.3.0-4jpp
- fix strange permissions

* Fri Apr 11 2003 David Walluck <david@anti-microsoft.org> 0:2.3.0-3jpp
- rebuild for jpackage 1.5

* Wed Jan 22 2003 David Walluck <david@anti-microsoft.org> 2.3.0-2jpp
- Requires/BuildRequires: xalan-j2
- update %%description

* Mon Jan 13 2003 David Walluck <david@anti-microsoft.org> 2.3.0-1jpp
- version 2.3.0 (first jakarta release)

* Tue May 07 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 2.2-5jpp 
- vendor, distribution, group tags
- versioned dir for javadoc
- section macro

* Sat Dec 1 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 2.2-4jpp
- javadoc in javadoc package

* Wed Nov 21 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 2.2-3jpp
- removed packager tag
- new jpp extension
- fixed url

* Sat Oct 6 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 2.2-2jpp
- first unified release
- used original tarball
- s/jPackage/JPackage

* Thu Aug 30 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 2.2-1jpp
- first Mandrake release
